# AdviserResultResponseMetadataDistribution

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**codename** | **str** | Codename of environment in which the analysis was performed  |
**id** | **str** | Identifier of environment in which the analysis was performed  |
**like** | **str** | Similar environments in comparison to environment in which the analysis was performed  |
**version** | **str** | A string representation of environment version |
**version_parts** | [**AdviserResultResponseMetadataDistributionVersionParts**](AdviserResultResponseMetadataDistributionVersionParts.md) |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

